@@ -2,5 +2,5 @@ var searchData=
 [
   ['helper_20class_20to_20create_20xml_20files_20using_20printf_20fprintf_20cout_20functions_0',['Helper class to create XML files using &quot;printf&quot;, &quot;fprintf&quot;, &quot;cout&quot;,... functions.',['../group__ToXMLStringTool.html',1,'']]],
   ['helper_20class_20to_20include_20binary_20data_20inside_20xml_20strings_20using_20base64_20encoding_1',['Helper class to include binary data inside XML strings using &quot;Base64 encoding&quot;.',['../group__XMLParserBase64Tool.html',1,'']]],
-  ['helper_20functions_20use_20in_20conjunction_20with_20the_20update_20add_20functions_2',['Position helper functions (use in conjunction with the update&amp;add functions)',['../group__xmlPosition.html',1,'']]]
+  ['helper_20functions_20use_20in_20conjunction_20with_20the_20update_20add_20functions_2',['Position helper functions (use in conjunction with the update&amp;amp;add functions)',['../group__xmlPosition.html',1,'']]]
 ];
