@@ -3,6 +3,6 @@ var searchData=
   ['parser_0',['The XML parser',['../group__XMLParserGeneral.html',1,'']]],
   ['parsing_20xml_20files_20strings_20to_20an_20xmlnode_20structure_20and_20rendering_20xmlnode_20s_20to_20files_20string_1',['Parsing XML files/strings to an XMLNode structure and Rendering XMLNode&apos;s to files/string.',['../group__conversions.html',1,'']]],
   ['place_20construction_2',['Tools for in-place construction',['../group__OFin__place__helpers.html',1,'']]],
-  ['position_20helper_20functions_20use_20in_20conjunction_20with_20the_20update_20add_20functions_3',['Position helper functions (use in conjunction with the update&amp;add functions)',['../group__xmlPosition.html',1,'']]],
+  ['position_20helper_20functions_20use_20in_20conjunction_20with_20the_20update_20add_20functions_3',['Position helper functions (use in conjunction with the update&amp;amp;add functions)',['../group__xmlPosition.html',1,'']]],
   ['printf_20fprintf_20cout_20functions_4',['Helper class to create XML files using &quot;printf&quot;, &quot;fprintf&quot;, &quot;cout&quot;,... functions.',['../group__ToXMLStringTool.html',1,'']]]
 ];
